@@ -3,6 +3,7 @@ mod dynamodb;
 mod mysql;
 mod postgres;
 mod redis;
+mod snowflake;
 mod sqlite;
 mod tidb;
 mod tikv;
@@ -12,6 +13,7 @@ pub use dynamodb::DynamoDB;
 pub use mysql::MySQL;
 pub use postgres::Postgres;
 pub use redis::Redis;
+pub use snowflake::Snowflake;
 pub use sqlite::SQLite;
 pub use tidb::TiDB;
 pub use tikv::TiKV;
